@@ -4,7 +4,7 @@
 #' @format ## `Fm`
 #' A data frame with 9 rows and 15 columns:
 #' \describe{
-#'   \item{chl.c1}{XX}
+#'   \item{chl_c1}{XX}
 #'   \item{Per}{XX}
 #'   \item{X19but}{XX}
 #'   ...
@@ -19,7 +19,7 @@
 #' @format ## `Sm`
 #' A data frame with 29 rows and 15 columns:
 #' \describe{
-#'   \item{chl.c1}{XX}
+#'   \item{chl_c1}{XX}
 #'   \item{Per}{XX}
 #'   \item{X19but}{XX}
 #'   ...
@@ -28,6 +28,35 @@
 "Sm"
 
 
+#' Fp data
+#'
+#'
+#' @format ## `Fp`
+#' A data frame with 9 rows and 15 columns:
+#' \describe{
+#'   \item{chl_c1}{XX}
+#'   \item{Per}{XX}
+#'   \item{X19but}{XX}
+#'   ...
+#' }
+#' @source XX
+"Fp"
+
+
+#' Sp data
+#'
+#'
+#' @format ## `Sp`
+#' A data frame with 29 rows and 15 columns:
+#' \describe{
+#'   \item{chl_c1}{XX}
+#'   \item{Per}{XX}
+#'   \item{X19but}{XX}
+#'   ...
+#' }
+#' @source XX
+"Sp"
+
 
 #' min_max data
 #'
